.. highlight:: shell

========
mihifepe
========

.. image:: https://img.shields.io/pypi/v/mihifepe.svg
        :target: https://pypi.python.org/pypi/mihifepe
        :alt: Release status

.. image:: https://img.shields.io/travis/cloudbopper/mihifepe.svg
        :target: https://travis-ci.org/cloudbopper/mihifepe
        :alt: Build status

.. image:: https://readthedocs.org/projects/mihifepe/badge/?version=latest
        :target: https://mihifepe.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/cloudbopper/mihifepe/shield.svg
        :target: https://pyup.io/repos/github/cloudbopper/mihifepe/
        :alt: Updates


--------
Overview
--------

``mihifepe`` is a library that implements Model Interpretability via Hierarchical Feature Perturbation ([Paper link here])).

-------------
Documentation
-------------

https://mihifepe.readthedocs.io

------------
Installation
------------

Recommended installation method is via `virtual environments`_ and pip_.

When making the virtual environment, specify python3 as the python executable (python3 version must be 3.5+)::

    mkvirtualenv -p python3 mihifepe_env

To install the latest stable release::

    pip install mihifepe

Or to install the latest development version from GitHub::

    pip install git+https://github.com/cloudbopper/mihifepe.git@master#egg=mihifepe

.. _pip: https://pip.pypa.io/
.. _virtual environments: https://python-guide-cn.readthedocs.io/en/latest/dev/virtualenvs.html

-----------
Development
-----------

https://mihifepe.readthedocs.io/en/latest/contributing.html

-----
Usage
-----

https://mihifepe.readthedocs.io/en/latest/usage.html

-------
License
-------

``mihifepe`` is free, open source software, released under the MIT license. See LICENSE_ for details.

.. _LICENSE: https://github.com/cloudbopper/mihifepe/blob/master/LICENSE

-------
Contact
-------

`Akshay Sood`_

.. _Akshay Sood: https://github.com/cloudbopper
